@@ -55,6 +55,15 @@ define ([
             'start': dactionStart('demoAction')
         });
 
+        // general actions
+        target.push('drowselectListen', {
+            'name': 'drowselectListen',
+            'type': 'daction',
+            'menuText': 'drowselectListen',
+            'aclProfile': 'passerby',
+            'start': dactionStart('drowselectListen')
+        });
+
         // Employee actions
         target.push('myProfile', {
             'name': 'myProfile',
@@ -107,13 +116,34 @@ define ([
         });
 
         // Privhistory actions
-        target.push('actionPrivHistory', {
+        target.push('actionPrivHistory', { // read-only
             'name': 'actionPrivHistory',
             'type': 'daction',
             'menuText': 'Privilege (status) history',
             'aclProfile': 'passerby',
             'start': dactionStart('actionPrivHistory')
         });
+        target.push('actionPrivHistoryEdit', { // read-write
+            'name': 'actionPrivHistoryEdit',
+            'type': 'daction',
+            'menuText': 'Privilege (status) history EDIT',
+            'aclProfile': 'admin',
+            'start': dactionStart('actionPrivHistoryEdit')
+        });
+        target.push('privHistorySaveAction', {
+            'name': 'privHistorySaveAction',
+            'type': 'daction',
+            'menuText': 'Commit to database',
+            'aclProfile': 'admin',
+            'start': dactionStart('privHistorySaveAction')
+        });
+        target.push('privHistoryDeleteAction', {
+            'name': 'privHistoryDeleteAction',
+            'type': 'daction',
+            'menuText': 'Delete record',
+            'aclProfile': 'admin',
+            'start': dactionStart('privHistoryDeleteAction')
+        });
         
         // Run unit tests
         target.push('unitTests', {
