@@ -40,12 +40,14 @@ define ([
     'current-user',
     'app/lib',
     'app/emp-lib',
+    'app/rest-lib',
     'app/prototypes',
     'target'
 ], function (
     currentUser,
     lib,
     empLib,
+    restLib,
     prototypes,
     target
 ) {
@@ -150,6 +152,46 @@ define ([
             }
         }); // target.push('searchEmpNothingFound'
 
+        target.push('restServerDetails', {
+            'name': 'restServerDetails',
+            'type': 'dform',
+            'menuText': 'REST server',
+            'title': 'REST server details',
+            'preamble': '<b>URI</b> used by this App::Dochazka::WWW instance to communicate ' +
+                        'with REST server;<br><b>version</b> of App::Dochazka::REST running ' +
+                        'on REST server',
+            'aclProfile': 'admin',
+            'entriesRead': [entries.rSDurl, entries.rSDversion],
+            'hook': restLib.restServerDetails,
+            'miniMenu': {
+                entries: [],
+                back: ['To leave this page, press ENTER or click the Submit button', 'mainMenu']
+            }
+        }); // target.push('restServerDetails'
+
+        target.push('privHistoryAddRecord', {
+            'name': 'privHistoryAddRecord',
+            'type': 'dform',
+            'menuText': 'Add record',
+            'title': 'Add privhistory (status) record',
+            'preamble': '<b>Effective</b> date format YYYY-MM-DD;<br>' +
+                        '<b>Priv</b> one of (passerby, inactive, active, admin)',
+            'aclProfile': 'admin',
+            'entriesRead': [entries.ePnick], 
+            'entriesWrite': [entries.pHeffective, entries.pHpriv],
+            'hook': function () {
+                    return {
+                        'nick': currentUser('obj').nick,
+                        'effective': null,
+                        'priv': null
+                    };
+                },
+            'miniMenu': {
+                entries: ['privHistorySaveAction'],
+                back: ['Back', 'drowselectListen']
+            }
+        }); // target.push('privHistoryAddRecord'
+
     }; // return function ()
     
 });
