@@ -49,8 +49,9 @@ define ([
     var entries = dochazkaLib.entries;
 
     return function () {
-        target.push('privHistoryReadOnly', {
-            'name': 'privHistoryReadOnly',
+
+        target.push('privHistoryDtable', {
+            'name': 'privHistoryDtable',
             'type': 'dtable',
             'menuText': 'Privilege (status) history',
             'title': 'Privilege (status) history',
@@ -63,6 +64,7 @@ define ([
                 back: ['Back', 'mainPriv']
             }
         });
+
     };
     
 });
