@@ -121,6 +121,7 @@ define ([
            'pHpriv': {
                name: 'pHpriv',
                aclProfileRead: 'passerby',
+               aclProfileWrite: 'admin',
                text: 'Priv',
                prop: 'priv',
                maxlen: 10
@@ -128,9 +129,24 @@ define ([
            'pHeffective': {
                name: 'pHeffective',
                aclProfileRead: 'passerby',
+               aclProfileWrite: 'admin',
                text: 'Effective date',
                prop: 'effective',
                maxlen: 30
+           },
+           'rSDurl': {
+               name: 'rSDurl',
+               aclProfileRead: 'passerby',
+               text: 'URI',
+               prop: 'url',
+               maxlen: 60
+           },
+           'rSDversion': {
+               name: 'rSDversion',
+               aclProfileRead: 'passerby',
+               text: 'Version',
+               prop: 'version',
+               maxlen: 30
            }
         },
 
@@ -191,6 +207,6 @@ define ([
             r += 'https://github.com/smithfarm/dochazka/issues</a>';
             return r;
         }
-   
+
     };
 });
